@@ -1,18 +1,18 @@
 ;;; epkg-marginalia.el --- Show Epkg information in completion annotations  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2021-2025 Jonas Bernoulli
+;; Copyright (C) 2021-2026 Jonas Bernoulli
 
 ;; Author: Jonas Bernoulli <emacs.epkg-marginalia@jonas.bernoulli.dev>
 ;; Homepage: https://github.com/emacscollective/epkg-marginalia
 ;; Keywords: tools
 
-;; Package-Version: 20251101.2117
-;; Package-Revision: 681295f585ef
+;; Package-Version: 20260301.1306
+;; Package-Revision: d6ccf20529c3
 ;; Package-Requires: (
 ;;     (emacs     "28.1")
 ;;     (compat    "30.1")
 ;;     (epkg       "4.1")
-;;     (marginalia "2.4"))
+;;     (marginalia "2.9"))
 
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -50,11 +50,12 @@
 (require 'borg nil t)
 
 (eval-when-compile (require 'package))
-(declare-function package-load-all-descriptors "package" ())
+(declare-function package-load-all-descriptors "package-activate" ())
 (declare-function package-read-all-archive-contents "package" ())
 (declare-function package--from-builtin "package" (bi-desc))
-(declare-function package-version-join "package" (vlist))
-(declare-function package-installed-p "package" (package &optional min-version))
+(declare-function package-version-join "package-activate" (vlist))
+(declare-function package-installed-p "package-activate"
+                  (package &optional min-version))
 (defvar package--builtins)
 (defvar package--initialized)
 (defvar package-alist)
@@ -99,22 +100,22 @@ Uses information provided by `borg', `epkg' and `package'."
         :truncate (if (and desc epkg-marginalia-show-version) 16 0)
         :face 'marginalia-version)
        ((cond
-         ((and desc (eq (package-desc-dir desc) 'builtin))
-          (propertize "builtin" 'face 'marginalia-installed))
-         ((and epkg
-               (fboundp 'borg-drones)
-               (member name (borg-drones)))
-          (propertize "assimilated" 'face 'marginalia-installed))
-         ((and epkg
-               (fboundp 'borg-clones)
-               (member name (borg-clones)))
-          (propertize "cloned" 'face 'marginalia-installed))
-         ((and desc (package-installed-p desc))
-          (propertize "installed" 'face 'marginalia-installed))
-         (epkg
-          (propertize "mirror" 'face 'marginalia-archive))
-         (desc
-          (propertize (package-desc-archive desc) 'face 'marginalia-archive)))
+          ((and desc (eq (package-desc-dir desc) 'builtin))
+           (propertize "builtin" 'face 'marginalia-installed))
+          ((and epkg
+                (fboundp 'borg-drones)
+                (member name (borg-drones)))
+           (propertize "assimilated" 'face 'marginalia-installed))
+          ((and epkg
+                (fboundp 'borg-clones)
+                (member name (borg-clones)))
+           (propertize "cloned" 'face 'marginalia-installed))
+          ((and desc (package-installed-p desc))
+           (propertize "installed" 'face 'marginalia-installed))
+          (epkg
+           (propertize "mirror" 'face 'marginalia-archive))
+          (desc
+           (propertize (package-desc-archive desc) 'face 'marginalia-archive)))
         :truncate 12)
        ((or (and epkg (oref epkg summary))
             (and desc (package-desc-summary desc)))
@@ -125,5 +126,6 @@ Uses information provided by `borg', `epkg' and `package'."
 (provide 'epkg-marginalia)
 ;; Local Variables:
 ;; indent-tabs-mode: nil
+;; lisp-indent-local-overrides: ((cond . 0) (interactive . 0))
 ;; End:
 ;;; epkg-marginalia.el ends here
